<Layout.Public title="Page Not Found">
  <div class="not-found-page">
    <header class="not-found-page__header">
      <h1>
        Page Not&nbsp;Found
      </h1>
    </header>
    <div class="not-found-page__content">
      <p>The page you were looking for does not&nbsp;exist.</p>
      <p>It might have been renamed or&nbsp;deleted.</p>
      <footer class="not-found-page__footer">
        <a href="/" class="link">Go back to the home&nbsp;page</a>
      </footer>
    </div>
  </div>
  <!--
  WARNING:
  If this page is smaller than 512 bytes, then Internet Explorer and Chrome|Chromium will display their own built-in 404 page and the Internet will be flooded with ones and zeros.
  -->
</Layout.Public>
