{#def title='', lang='en' #}

<!DOCTYPE html>
<html lang="{{ lang }}">
<head>
	<meta charset="utf-8">
	<title>{{ title }}</title>
	<meta name="viewport" content="width=device-width,initial-scale=1">
	<style></style>
</head>
<body>
	{{ content }}
</body>
</html>
