<Layout.Public title="Server Error">
  <div class="error-page">
    <header class="error-page__header">
      <h1>
        Something went&nbsp;wrong
      </h1>
    </header>
    <div class="error-page__content">
      <footer class="error-page__footer">
        <a href="/" class="link">Go back to the home page</a>
      </footer>
    </div>
  </div>
  <!--
  WARNING:
  If this page is smaller than 512 bytes, then Internet Explorer and Chrome|Chromium will display their own built-in 5XX page and the Internet will be flooded with ones and zeros.
  -->
</Layout.Public>
