"""
Import here all the models you want to be detected for migrations.
You can also do `from .your_model import *  #noqa` here
and, in your model file, use `__all__` to define what to import

Do not import `BaseModel` or `BaseMixin` here.
"""
from .base import db  # noqa
