{#def title = '', description='', lang='en' #}

{% if title %}{% set title = title + " | [[ app_name.title() ]]" %}{% endif -%}

<!DOCTYPE html>
<html lang="{{ lang }}">
<head>
	<meta charset="utf-8">
	<title>{{ title }}</title>
	<meta name="viewport" content="width=device-width, initial-scale=1, viewport-fit=cover">
	<link rel="icon" type="image/x-icon" href="{{ url_for('static', file='favicon.ico') }}">
	<link rel="stylesheet" href="{{ url_for('static', file='css/app.css') }}">
	<script>window.csrf_token = "{{ request.csrf_token }}";</script>
	<script src="{{ url_for('static', file='js/turbo.es2017-umd.js') }}" defer></script>
	<script src="{{ url_for('static', file='js/app.js') }}" defer></script>
	{{ catalog.render_assets() }}
	{% if title %}<meta property="og:title" content="{{ title }}">{% endif %}
	{% if description -%}<meta property="og:description" content="{{ description }}">{% endif -%}
</head>
<body {{ attrs.render() }}>
	{{ content }}
</body>
</html>
